Exception: Serviced::InvalidResultAccess

Inherits:
Error
  • Object
show all
Defined in:
lib/serviced/errors.rb

Overview

Raised when reading the value of a failure (or otherwise accessing a result in a way its status does not allow).