Exception: Serviced::MissingTransactionHandler

Inherits:
Error
  • Object
show all
Defined in:
lib/serviced/errors.rb

Overview

Raised when a transactional flow runs but no transaction handler is configured (for example, ActiveRecord is not loaded and nothing was set through Serviced.configure).