Exception: Serviced::Rollback
- Defined in:
- lib/serviced/errors.rb
Overview
Internal signal raised inside a transactional flow to force the underlying transaction to roll back. It never escapes the flow and is not part of the public API.
Internal signal raised inside a transactional flow to force the underlying transaction to roll back. It never escapes the flow and is not part of the public API.